@@ -84,8 +84,8 @@ func (p *Popeye) List(ctx context.Context, ns string) ([]runtime.Object, error)
 
 	buff := readWriteCloser{Buffer: bytes.NewBufferString("")}
 	popeye.SetOutputTarget(buff)
-	if _, err = popeye.Sanitize(); err != nil {
-		log.Debug().Msgf("BOOM %#v", *flags.Sections)
+	if _, _, err = popeye.Sanitize(); err != nil {
+		log.Error().Err(err).Msgf("BOOM %#v", *flags.Sections)
 		return nil, err
 	}
 
